@@ -2,7 +2,7 @@
 
 /*
  * File "udf_discinfo.c" is part of the UDFclient toolkit.
- * File $Id: udf_discop.c,v 1.80 2016/04/25 21:01:40 reinoud Exp $ $Name:  $
+ * File $Id: udf_discop.c,v 1.81 2017/01/16 14:33:06 reinoud Exp $ $Name:  $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -1158,6 +1158,12 @@ int udf_discinfo_alter_perception(struct udf_discinfo *disc, uint32_t sec_size,
 		return EINVAL;
 	}
 
+	if (stat.st_size / sec_size >= (uint32_t) -1)
+	{
+		fprintf(stderr, "Disc needs to many logical sectors, please increase blocksize\n");
+		return EINVAL;
+	}
+
 	if (num_sectors < 300) {
 		fprintf(stderr, "Disc size too small to put an UDF filingsystem on\n");
 		return EINVAL;
